The function summarizes the sampling effort each year based on SLF records from government sources, using the alpha convex hull to delineate the invaded area.

sampling_effort(data = lyde, alpha = 19746.64, buffer_width = 10)

Arguments

data

Unless otherwise specified, lydemapr::lyde

alpha

The coarseness of the hull drawing. Recommended value is based on cross validation work

buffer_width

A necessary parameter for the construction of a shape from the hull boundary (10 m recommended).

Value

A table

Examples

if (FALSE) { # \dontrun{
} # }