The function takes SLF occurrence data and creates a boundary that defines their invaded range in the US.
alphahull_sf(
data = lyde,
alpha = 19746.64,
bio_year = NULL,
use_public = FALSE,
only_established = TRUE,
buffer_width = 10
)Unless otherwise specified, lydemapr::lyde
The coarseness of the hull drawing. Recommended value is based on cross validation work
A double limiting lyde observations to on or before the biological year specified.
A logical specifying whether public reports should be included (FALSE by default).
A logical specifying whether only points with established SLF should be included (TRUE by default).
A necessary parameter for the construction of a shape from the hull (10 m recommended, so that is the default).
An sf object containing the alpha convex hull polygon.
From the work of: Keller J, Bona SD, Helmus MR. 2026. Leveraging spatial scale and temporal variation to track the spread rate of invasive spotted lanternflies (Lycorma delicatula). NeoBiota. 106:287–307. https://doi.org/10.3897/neobiota.106.177041
if (FALSE) { # \dontrun{
outres <- alphahull_sf(data = lyde,
alpha = 12000,
bio_year = 2025,
use_public = FALSE,
only_established = TRUE,
buffer_width = 10)
} # }