R/append_inat.R
append_inat.RdThe function tidies and cleans downloaded spotted lanternfly data from iNaturalist's export page and appends it to `lyde`.
append_inat(path, round = TRUE)A cleaned tibble
This should be applied to a dataset downloaded through the link: `https://www.inaturalist.org/observations/export`
Or for the direct search query: `https://www.inaturalist.org/observations/export?search_on=names&quality_grade=research&identifications=most_agree&captive=false&place_id=1&taxon_id=324726`
if (FALSE) { # \dontrun{
# return lyde with iNaturalist observations with the raw latitude/longitude coordinates
df <- append_inat("observations-686514.csv", round = FALSE)
# return lyde with iNaturalist observations with the latitude/longitude coordinates rounded to the 1km grid
df <- append_inat("observations-686514.csv", round = TRUE)
} # }