The function summarizes the sampling effort each year based on SLF records from government sources, using the alpha convex hull to delineate the invaded area.
sampling_effort(data = lyde, alpha = 19746.64, buffer_width = 10)A table
if (FALSE) { # \dontrun{
} # }